@@ -20,6 +20,7 @@
  */
 /**
  * SECTION: gesasset
+ * @title: GESAsset
  * @short_description: Represents usable resources inside the GStreamer Editing Services
  *
  * The Assets in the GStreamer Editing Services represent the resources
@@ -690,7 +691,7 @@ ges_asset_set_proxy (GESAsset * asset, GESAsset * proxy)
     if (asset->priv->proxies) {
       GESAsset *old_proxy = GES_ASSET (asset->priv->proxies->data);
 
-      GES_ASSET (asset->priv->proxies->data)->priv->proxy_target = NULL;
+      old_proxy->priv->proxy_target = NULL;
       g_object_notify_by_pspec (G_OBJECT (old_proxy),
           _properties[PROP_PROXY_TARGET]);
     }
@@ -725,6 +726,8 @@ ges_asset_set_proxy (GESAsset * asset, GESAsset * proxy)
     GST_ERROR_OBJECT (asset,
         "Trying to use %s as a proxy, but it is already proxying %s",
         proxy->priv->id, proxy->priv->proxy_target->priv->id);
+
+    return FALSE;
   }
 
   if (g_list_find (proxy->priv->proxies, asset)) {
