@@ -104,7 +104,7 @@ GST_START_TEST (test_test_source_properties)
 
   /* Test mute support */
   g_object_set (clip, "mute", TRUE, NULL);
-  fail_unless (ges_timeline_commit (timeline));
+  fail_if (ges_timeline_commit (timeline));
   nle_object_check (ges_track_element_get_nleobject (trackelement), 420, 510,
       120, 510, MIN_NLE_PRIO + TRANSITIONS_HEIGHT, FALSE);
   g_object_set (clip, "mute", FALSE, NULL);
@@ -405,6 +405,10 @@ ges_suite (void)
   Suite *s = suite_create ("ges-backgroundsource");
   TCase *tc_chain = tcase_create ("backgroundsource");
 
+  if (atexit (ges_deinit) != 0) {
+    GST_ERROR ("failed to set ges_deinit as exit function");
+  }
+
   suite_add_tcase (s, tc_chain);
 
   tcase_add_test (tc_chain, test_test_source_basic);
